@@ -147,17 +147,18 @@ class Object():
 
         self.__dict__.update(data)
 
-    def update(self, **kwargs):
+    def update(self, data=None):
         """
         Updates the object properties in Arena based on attributes passed in.
 
-        Keyword arguments are required
+        Required arguments:
+
+        - data - A dictionary of object properties to update
         """
 
-        if not kwargs:
-            raise ValueError("Must include parameter keyword arguments")
+        data=data or self.__dict__
 
-        data= self._client._put(self.endpoint, kwargs)
+        data= self._client._put(self.endpoint, data)
 
         self.__dict__.update(data)
 
